==> verttice_ui-0.0.79.tar.gz: lib/src/widgets/data_factory/table_factory/filter_view.dart <==
import 'package:collection/collection.dart';
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_ui/src/const/box_sizes.dart';
import 'package:verttice_ui/src/const/icons.dart';
import 'package:flutter/material.dart';
import 'package:verttice_ui/src/widgets/data_factory/form_factory/form_factory.dart';
import 'package:verttice_ui/src/widgets/data_factory/form_factory/form_fields.dart';
import 'package:verttice_ui/src/widgets/themed_app_bar.dart';

import '../common/common_index.dart';

class FilterView extends StatefulWidget {
  final Function(List<FilterField>) filterCallback;
  final Function() clearFilterCallback;
  final List<FilterField>? filter;
  final FormItem column;

  const FilterView({
    Key? key,
    required this.filterCallback,
    required this.clearFilterCallback,
    required this.column,
    this.filter,
  }) : super(key: key);

  @override
  State<FilterView> createState() => _FilterViewState();
}

class _FilterViewState extends State<FilterView> {
  late List<FilterField> _filter;

  @override
  void initState() {
    super.initState();
    if (widget.filter == null) {
      _filter = [
        FilterField(
          field: widget.column.field.searchPath,
          filterType: widget.column.field.filterType,
        )
      ];
    } else {
      _filter = widget.filter!;
    }
  }

  @override
  void didUpdateWidget(covariant FilterView oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (!const DeepCollectionEquality().equals(_filter, widget.filter)) {
      if (widget.filter == null) {
        _filter = [
          FilterField(
            field: widget.column.field.searchPath,
            filterType: widget.column.field.filterType,
          )
        ];
      } else {
        _filter = widget.filter!;
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        ThemedAppBar(
          actions: [
            if (isTextField(widget.column))
              Tooltip(
                message: 'Add filter',
                child: IconButton(
                  onPressed: () {
                    setState(() {
                      _filter.add(
                        FilterField(
                          field: widget.column.field.searchPath,
                          filterType: widget.column.field.filterType,
                        ),
                      );
                    });
                  },
                  icon: ThemedIcons.add(),
                ),
              )
          ],
        ),
        Expanded(
          child: !isTextField(widget.column)
              ? Center(
                  child: FormFactory(
                    formItems: [widget.column],
                    gridView: true,
                    isFilter: true,
                    formState: {widget.column.field.name: _filter.first.value},
                    onChanged: (name, data) {
                      setState(() {
                        _filter.first = FilterField(
                          field: widget.column.field.searchPath,
                          filterType: widget.column.field.filterType,
                          value: data,
                        );
                      });
                    },
                  ),
                )
              : ListView(
                  children: _filter
                      .mapIndexed(
                        (index, e) => Row(
                          crossAxisAlignment: CrossAxisAlignment.center,
                          mainAxisAlignment: MainAxisAlignment.spaceAround,
                          children: [
                            Expanded(
                              child: FormFactory(
                                formItems: [widget.column],
                                gridView: true,
                                isFilter: true,
                                formState: {
                                  widget.column.field.name: e.value,
                                },
                                onChanged: (name, data) {
                                  setState(() {
                                    _filter[index] = FilterField(
                                      field: widget.column.field.searchPath,
                                      filterType:
                                          widget.column.field.filterType,
                                      value: data,
                                    );
                                  });
                                },
                              ),
                            ),
                            if (_filter.length > 1)
                              Padding(
                                padding: const EdgeInsets.all(12.0),
                                child: Tooltip(
                                  message: 'Remove this filter',
                                  child: IconButton(
                                    onPressed: () {
                                      setState(() {
                                        _filter.removeAt(index);
                                      });
                                    },
                                    icon: ThemedIcons.clear(),
                                  ),
                                ),
                              )
                          ],
                        ),
                      )
                      .toList(),
                ),
        ),
        SizedBox(
          height: 50,
          child: Row(children: [
            sizedBoxW8,
            TextButton(
              onPressed: () {
                widget.clearFilterCallback();
                Navigator.of(context).pop();
              },
              child: const Text(
                'Clear Filter',
                style: TextStyle(
                  color: Colors.red,
                ),
              ),
            ),
            sizedBoxW8,
            TextButton(
              onPressed: () {
                widget.filterCallback(_filter);
                Navigator.of(context).pop();
              },
              child: const Text(
                'Apply Filter',
                style: TextStyle(
                  color: Colors.green,
                ),
              ),
            ),
            sizedBoxW8,
            Tooltip(
              message: "Cancel",
              child: TextButton(
                onPressed: () {
                  Navigator.of(context).pop();
                },
                child: const Text("Cancel"),
              ),
            ),
            sizedBoxW8,
          ]),
        )
      ],
    );
  }
}

==> verttice_ui-0.0.97.tar.gz: lib/src/widgets/data_factory/table_factory/filter_view.dart <==
import 'package:collection/collection.dart';
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_ui/src/const/box_sizes.dart';
import 'package:verttice_ui/src/const/icons.dart';
import 'package:flutter/material.dart';
import 'package:verttice_ui/src/widgets/data_factory/form_factory/form_factory.dart';
import 'package:verttice_ui/src/widgets/data_factory/form_factory/form_fields.dart';
import 'package:verttice_ui/src/widgets/themed_widgets/themed_widgets_index.dart';

class FilterView extends StatefulWidget {
  final Function(List<FilterField>) filterCallback;
  final Function() clearFilterCallback;
  final List<FilterField>? filter;
  final FormItem column;

  const FilterView({
    Key? key,
    required this.filterCallback,
    required this.clearFilterCallback,
    required this.column,
    this.filter,
  }) : super(key: key);

  @override
  State<FilterView> createState() => _FilterViewState();
}

class _FilterViewState extends State<FilterView> {
  late List<FilterField> _filter;

  @override
  void initState() {
    super.initState();
    if (widget.filter == null) {
      _filter = [
        FilterField(
          field: widget.column.field.searchPath,
          filterType: widget.column.field.filterType,
        )
      ];
    } else {
      _filter = widget.filter!;
    }
  }

  @override
  void didUpdateWidget(covariant FilterView oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (!const DeepCollectionEquality().equals(_filter, widget.filter)) {
      if (widget.filter == null) {
        _filter = [
          FilterField(
            field: widget.column.field.searchPath,
            filterType: widget.column.field.filterType,
          )
        ];
      } else {
        _filter = widget.filter!;
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        ThemedAppBar(
          actions: [
            if (widget.column.field.filterType == FilterTypesFF.string ||
                widget.column.field.filterType == FilterTypesFF.stringList)
              Tooltip(
                message: 'Add filter',
                child: IconButton(
                  onPressed: () {
                    setState(() {
                      _filter.add(
                        FilterField(
                          field: widget.column.field.searchPath,
                          filterType: widget.column.field.filterType,
                        ),
                      );
                    });
                  },
                  icon: ThemedIcons.add(),
                ),
              )
          ],
        ),
        Expanded(
          child: !(widget.column.field.filterType == FilterTypesFF.string ||
                  widget.column.field.filterType == FilterTypesFF.stringList)
              ? Center(
                  child: FormFactory(
                    formItems: [widget.column],
                    gridView: true,
                    isFilter: true,
                    formState: {widget.column.field.name: _filter.first.value},
                    onChanged: (name, data) {
                      setState(() {
                        _filter.first = FilterField(
                          field: widget.column.field.searchPath,
                          filterType: widget.column.field.filterType,
                          value: data,
                        );
                      });
                    },
                  ),
                )
              : ListView(
                  children: _filter
                      .mapIndexed(
                        (index, e) => Row(
                          crossAxisAlignment: CrossAxisAlignment.center,
                          mainAxisAlignment: MainAxisAlignment.spaceAround,
                          children: [
                            Expanded(
                              child: FormFactory(
                                formItems: [widget.column],
                                gridView: true,
                                isFilter: true,
                                formState: {
                                  widget.column.field.name: e.value,
                                },
                                onChanged: (name, data) {
                                  setState(() {
                                    _filter[index] = FilterField(
                                      field: widget.column.field.searchPath,
                                      filterType:
                                          widget.column.field.filterType,
                                      value: data,
                                    );
                                  });
                                },
                              ),
                            ),
                            if (_filter.length > 1)
                              Padding(
                                padding: const EdgeInsets.all(12.0),
                                child: Tooltip(
                                  message: 'Remove this filter',
                                  child: IconButton(
                                    onPressed: () {
                                      setState(() {
                                        _filter.removeAt(index);
                                      });
                                    },
                                    icon: ThemedIcons.clear(),
                                  ),
                                ),
                              )
                          ],
                        ),
                      )
                      .toList(),
                ),
        ),
        SizedBox(
          height: 50,
          child: Row(children: [
            sizedBoxW8,
            TextButton(
              onPressed: () {
                widget.clearFilterCallback();
                Navigator.of(context).pop();
              },
              child: const Text(
                'Clear Filter',
                style: TextStyle(
                  color: Colors.red,
                ),
              ),
            ),
            sizedBoxW8,
            TextButton(
              onPressed: () {
                widget.filterCallback(_filter);
                Navigator.of(context).pop();
              },
              child: const Text(
                'Apply Filter',
                style: TextStyle(
                  color: Colors.green,
                ),
              ),
            ),
            sizedBoxW8,
            Tooltip(
              message: "Cancel",
              child: TextButton(
                onPressed: () {
                  Navigator.of(context).pop();
                },
                child: const Text("Cancel"),
              ),
            ),
            sizedBoxW8,
          ]),
        )
      ],
    );
  }
}
